#!/bin/sh

# Usage:
# sudo ./install.sh
#
# Install Fade In from the binary tarball (.tar.gz)
# basically replicating .deb or .rpm installation

if ! [ $# = 0 ]; then
	echo "Fade In .tar.gz installer"
	echo "Usage: sudo ./install.sh"
	exit
fi

echo "Installing Fade In to /usr/share/fadein..."

# Check if root
if ! [ $(id -u) = 0 ]; then
	echo "Please re-run using sudo: sudo ${0}" 
	exit 1
fi

echo "Copying program files to /usr/share/..."
cp -R usr/share/fadein /usr/share/

echo "Creating symlink /usr/bin/fadein..."
ln -s /usr/share/fadein/fadein /usr/bin/fadein

# MIME type
if command -v xdg-mime >/dev/null 2>&1; then
	echo "Adding MIME type..."
	xdg-mime install --novendor usr/share/mime/packages/fadein.xml
fi

# Install icon resources
if command -v xdg-icon-resource >/dev/null 2>&1; then
	echo "Installing application icons..."
	xdg-icon-resource install --novendor --size 16 usr/share/fadein/icon_app/fadein_icon_16x16.png fadein
	xdg-icon-resource install --novendor --size 24 usr/share/fadein/icon_app/fadein_icon_24x24.png fadein
	xdg-icon-resource install --novendor --size 32 usr/share/fadein/icon_app/fadein_icon_32x32.png fadein
	xdg-icon-resource install --novendor --size 48 usr/share/fadein/icon_app/fadein_icon_48x48.png fadein
	xdg-icon-resource install --novendor --size 64 usr/share/fadein/icon_app/fadein_icon_64x64.png fadein
	xdg-icon-resource install --novendor --size 96 usr/share/fadein/icon_app/fadein_icon_96x96.png fadein
	xdg-icon-resource install --novendor --size 128 usr/share/fadein/icon_app/fadein_icon_128x128.png fadein
	xdg-icon-resource install --novendor --size 256 usr/share/fadein/icon_app/fadein_icon_256x256.png fadein
	xdg-icon-resource install --novendor --size 512 usr/share/fadein/icon_app/fadein_icon_512x512.png fadein

	# MIME type icons
	echo "Installing MIME type icons..."
	xdg-icon-resource install --context mimetypes --size 16 usr/share/fadein/icon_app/fadein_doc_16x16.png application-x-fadein-document
	xdg-icon-resource install --context mimetypes --size 24 usr/share/fadein/icon_app/fadein_doc_24x24.png application-x-fadein-document
	xdg-icon-resource install --context mimetypes --size 32 usr/share/fadein/icon_app/fadein_doc_32x32.png application-x-fadein-document
	xdg-icon-resource install --context mimetypes --size 48 usr/share/fadein/icon_app/fadein_doc_48x48.png application-x-fadein-document
	xdg-icon-resource install --context mimetypes --size 64 usr/share/fadein/icon_app/fadein_doc_64x64.png application-x-fadein-document
	xdg-icon-resource install --context mimetypes --size 96 usr/share/fadein/icon_app/fadein_doc_96x96.png application-x-fadein-document
	xdg-icon-resource install --context mimetypes --size 128 usr/share/fadein/icon_app/fadein_doc_128x128.png application-x-fadein-document
	xdg-icon-resource install --context mimetypes --size 256 usr/share/fadein/icon_app/fadein_doc_256x256.png application-x-fadein-document
	xdg-icon-resource install --context mimetypes --size 512 usr/share/fadein/icon_app/fadein_doc_512x512.png application-x-fadein-document
fi

# Desktop resource
if command -v xdg-desktop-menu >/dev/null 2>&1; then
	echo "Adding to menu..."
	xdg-desktop-menu install --novendor usr/share/applications/fadein.desktop
elif [ -d "/usr/share/applications" ]; then
	echo "Installing default .desktop file..."
	cp -R usr/share/applications/fadein.desktop /usr/share/applications/
fi
