#!/bin/sh

# Usage:
# sudo ./uninstall.sh
#
# Uninstall Fade In from the binary tarball (.tar.gz)
# basically replicating .deb or .rpm uninstallation

if ! [ $# = 0 ]; then
	echo "Fade In .tar.gz uninstaller"
	echo "Usage: sudo ./uninstall.sh"
	exit
fi

echo "Uninstalling Fade In..."

# Check if root
if ! [ $(id -u) = 0 ]; then
	echo "Please re-run using sudo: sudo ${0}" 
	exit 1
fi

echo "Removing program files..."
rm -rf /usr/share/fadein

if [ -L "/usr/bin/fadein" ]; then
	echo "Removing symlink..."
	rm /usr/bin/fadein
fi

# Install icon resources
if command -v xdg-icon-resource >/dev/null 2>&1; then
	echo "Uninstalling application icons..."
	xdg-icon-resource uninstall --size 16 fadein
	xdg-icon-resource uninstall --size 24 fadein
	xdg-icon-resource uninstall --size 32 fadein
	xdg-icon-resource uninstall --size 48 fadein
	xdg-icon-resource uninstall --size 64 fadein
	xdg-icon-resource uninstall --size 96 fadein
	xdg-icon-resource uninstall --size 128 fadein
	xdg-icon-resource uninstall --size 256 fadein
	xdg-icon-resource uninstall --size 512 fadein
	
	# MIME type icons
	echo "Unistalling MIME type icons..."
	xdg-icon-resource uninstall --context mimetypes --size 16 application-x-fadein-document
	xdg-icon-resource uninstall --context mimetypes --size 24 application-x-fadein-document
	xdg-icon-resource uninstall --context mimetypes --size 32 application-x-fadein-document
	xdg-icon-resource uninstall --context mimetypes --size 48 application-x-fadein-document
	xdg-icon-resource uninstall --context mimetypes --size 64 application-x-fadein-document
	xdg-icon-resource uninstall --context mimetypes --size 96 application-x-fadein-document
	xdg-icon-resource uninstall --context mimetypes --size 128 application-x-fadein-document
	xdg-icon-resource uninstall --context mimetypes --size 256 application-x-fadein-document
	xdg-icon-resource uninstall --context mimetypes --size 512 application-x-fadein-document
fi

if command -v xdg-mime >/dev/null 2>&1; then
	echo "Removing MIME type..."
	xdg-mime uninstall --novendor usr/share/mime/packages/fadein.xml
fi

if command -v xdg-desktop-menu >/dev/null 2>&1; then
	echo "Removing from menu..."
	xdg-desktop-menu uninstall --novendor usr/share/applications/fadein.desktop
fi

if [ -e "/usr/share/applications/fadein.desktop" ]; then
	echo "Removing .desktop file..."
	rm -rf /usr/share/applications/fadein.desktop
fi
